Package 'crayolaTAMM'

Title: Create "Crayola" Summary of TAMM File
Description: For a Chinook TAMM file from the FRAM modeling process, produces a file summarizing the impacts for each key stock, as well as identifying the fisheries that most impact that stock.
Authors: Robert Roose [aut, cre] (ORCID: <https://orcid.org/0000-0003-3785-5224>), Collin Edwards [aut] (ORCID: <https://orcid.org/0000-0002-4937-5159>)
Maintainer: Robert Roose <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-07-09 16:49:18 UTC
Source: https://github.com/cbedwards-dfw/crayolaTAMM

Help Index


Make workbook summary of Chinook TAMM

Description

Make workbook summary of Chinook TAMM

Usage

make_crayola_tamm(
  filepath,
  output_path = NULL,
  plot_width = 10,
  plot_height = 8,
  plot_units = "in",
  verbose = TRUE
)

Arguments

filepath

Filepath of TAMM, including .xlsx suffix

output_path

Filepath for resulting file. Optional; if not provided, will save in same folder as filepath with name of "{filepath}_Impacts_crayola.xlsx"

plot_width

Controls width of barplots in stock sheets. Numeric, defaults to 10

plot_height

Controls height of barplots in stock sheets. Numeric, defaults to 8

plot_units

Character string defining units of plot_width and plot_height. Defaults to "in", can also be "cm" or "px".

verbose

Should progress messages and saved filepath be printed to screen?

Value

Invisibly returns filepath of the summary file.